### Main Analyses
### We fit Generalized Additive Mixed Models (GAMMs, using 'bam', which is intended 
### for very large datasets) with Elo rank score as the DV, and age, personality, 
### and their interactions as IVs.

### The model sequence is as follows (running from less to more complex)
### 1. Elo ~ age
### 2. M1 + Dominance
### 3. M1 + Conscientiousness
### 4. M1 + Dominance + Conscientiousness
### 5. M4 + remaining 4 factors (O, N, A, E)
### (and at the request of a reviewer)
### 6. M5 + a random effect for date



library(openxlsx)
library(mgcv)
library(lme4)
library(gamm4)
library(car)
library(caret)
library(optimx)
library(bbmle)
library(ggplot2)
library(plyr)
library(itsadug)



### Read data
df_init_allNew = read.xlsx('GAMMdata.xlsx')



### Age only

start_time <- Sys.time() 
bam.card.init.cs.OnlyAge = bam(EloCardinal ~ ti(age_cz, bs='cs', k=7) + # age main effect - this was arrived at by looking at change in the spline by increasing k. No higher k altered the spline.
                             + s(chimpcode, bs='re') + s(chimpcode, age_cz, bs='re') # random intercept and slope
                             , family=binomial(link='logit')
                             , data=df_init_allNew
                             , method='fREML' 
)
end_time <- Sys.time()
end_time - start_time

gam.check(bam.card.init.cs.OnlyAge) # checks dfs and indicates if any changes should be made
summary(bam.card.init.cs.OnlyAge)
plot.gam(bam.card.init.cs.OnlyAge,select=1) # plots effects - which are key for interpretation - and other diagnostics



### D
start_time <- Sys.time() 
bam.card.init.cs.AgeDnr = bam(EloCardinal ~ ti(age_cz, bs='cs', k=7) + # age main effect
                               ti(D_new_resid, bs='cs') 
                             + ti(age_cz, D_new_resid, bs='cs')
                             + s(chimpcode, bs='re') + s(chimpcode, age_cz, bs='re') # random intercept and slope
                             + s(chimpcode, D_new_resid, bs='re')
                             , family=binomial(link='logit')
                             , data=df_init_allNew
                             , method='fREML' 
)
end_time <- Sys.time()
end_time - start_time

gam.check(bam.card.init.cs.AgeDnr) # checks dfs and indicates if any changes should be made
plot.gam(bam.card.init.cs.AgeDnr) # plots effects - which are key for interpretation - and other diagnostics
summary(bam.card.init.cs.AgeDnr)



### C
start_time <- Sys.time() 
bam.card.init.cs.AgeCr = bam(EloCardinal ~ ti(age_cz, bs='cs', k=7) + # age main effect
                                ti(C_resid, bs='cs') 
                              + ti(age_cz, C_resid, bs='cs')
                              + s(chimpcode, bs='re') + s(chimpcode, age_cz, bs='re') # random intercept and slope
                              + s(chimpcode, C_resid, bs='re')
                              , family=binomial(link='logit')
                              , data=df_init_allNew
                              , method='fREML' 
)
end_time <- Sys.time()
end_time - start_time 

gam.check(bam.card.init.cs.AgeCr) # checks dfs and indicates if any changes should be made
plot.gam(bam.card.init.cs.AgeCr) # plots effects - which are key for interpretation - and other diagnostics
summary(bam.card.init.cs.AgeCr)



### C + D
start_time <- Sys.time() 
bam.card.init.cs.AgeDnrCr = bam(EloCardinal ~ ti(age_cz, bs='cs', k=7) + # age main effect
                                  ti(D_new_resid, bs='cs') 
                             + ti(C_resid, bs='cs')
                             + ti(age_cz, D_new_resid, bs='cs')
                             + ti(age_cz, C_resid, bs='cs')
                             + s(chimpcode, bs='re') + s(chimpcode, age_cz, bs='re') # random intercept and slope
                             + s(chimpcode, D_new_resid, bs='re')
                             + s(chimpcode, C_resid, bs='re')
                             , family=binomial(link='logit')
                             , data=df_init_allNew
                             , method='fREML'
)
end_time <- Sys.time()
end_time - start_time 

gam.check(bam.card.init.cs.AgeDnrCr) # checks dfs and indicates if any changes should be made
plot.gam(bam.card.init.cs.AgeDnrCr) # plots effects - which are key for interpretation - and other diagnostics
summary(bam.card.init.cs.AgeDnrCr)



### All 6
start_time <- Sys.time() 
bam.card.init.cs.all.7 = bam(EloCardinal ~ ti(age_cz, bs='cs', k=7) + # age main effect
                                  ti(D_new_resid, bs='cs') 
                                + ti(C_resid, bs='cs')
                                + ti(Ext_cz, bs='cs') + ti(Agr_cz, bs='cs')
                                + ti(Opn_cz, bs='cs') + ti(Neu_cz, bs='cs')
                                + ti(age_cz, D_new_resid, bs='cs')
                                + ti(age_cz, C_resid, bs='cs')
                                + ti(age_cz, Ext_cz, bs='cs') + ti(age_cz, Agr_cz, bs='cs')
                                + ti(age_cz, Opn_cz, bs='cs') + ti(age_cz, Neu_cz, bs='cs')
                                + s(chimpcode, bs='re') + s(chimpcode, age_cz, bs='re') # random intercept and slope
                                + s(chimpcode, D_new_resid, bs='re')
                                + s(chimpcode, C_resid, bs='re')
                                + s(chimpcode, Ext_cz, bs='re') + s(chimpcode, Agr_cz, bs='re')
                                + s(chimpcode, Opn_cz, bs='re') + s(chimpcode, Neu_cz, bs='re')
                                , family=binomial(link='logit')
                                , data=df_init_allNew
                                , method='fREML' 
)
end_time <- Sys.time()
end_time - start_time

gam.check(bam.card.init.cs.all.7) # checks dfs and indicates if any changes should be made
plot.gam(bam.card.init.cs.all.7, select=2)
abline(h=0)

plot(bam.card.init.cs.all.7, select=3)
abline(h=0)

summary(bam.card.init.cs.all.7)



### Model comparisons

AICtab(bam.card.init.cs.OnlyAge, bam.card.init.cs.AgeDnr, bam.card.init.cs.AgeCr, bam.card.init.cs.AgeDnrCr, bam.card.init.cs.all.7
            , weights=TRUE, base=TRUE)


compareML(bam.card.init.cs.OnlyAge, bam.card.init.cs.AgeDnr)
compareML(bam.card.init.cs.OnlyAge, bam.card.init.cs.AgeCr)
compareML(bam.card.init.cs.AgeDnrCr, bam.card.init.cs.AgeCr)
compareML(bam.card.init.cs.OnlyAge, bam.card.init.cs.all.7)
compareML(bam.card.init.cs.AgeDnrCr, bam.card.init.cs.all.7)
## "all.7" model is the best



### + Date RE (reviewer request)
start_time <- Sys.time() 
bam.card.init.cs.allPlusDateRE = bam(EloCardinal ~ ti(age_cz, bs='cs', k=7) + # age main effect
                                       ti(D_new_resid, bs='cs') 
                                     + ti(C_resid, bs='cs')
                                     + ti(Ext_cz, bs='cs') + ti(Agr_cz, bs='cs')
                                     + ti(Opn_cz, bs='cs') + ti(Neu_cz, bs='cs')
                                     + ti(age_cz, D_new_resid, bs='cs')
                                     + ti(age_cz, C_resid, bs='cs')
                                     + ti(age_cz, Ext_cz, bs='cs') + ti(age_cz, Agr_cz, bs='cs')
                                     + ti(age_cz, Opn_cz, bs='cs') + ti(age_cz, Neu_cz, bs='cs')
                                     + s(as.numeric(date), bs='cs')
                                     + s(chimpcode, bs='re') + s(chimpcode, age_cz, bs='re') # random intercept and slope
                                     + s(chimpcode, D_new_resid, bs='re')
                                     + s(chimpcode, C_resid, bs='re')
                                     + s(chimpcode, Ext_cz, bs='re') + s(chimpcode, Agr_cz, bs='re')
                                     + s(chimpcode, Opn_cz, bs='re') + s(chimpcode, Neu_cz, bs='re')
                                     , family=binomial(link='logit')
                                     , data=df_init_allNew
                                     , method='fREML' 
)
end_time <- Sys.time()
end_time - start_time

gam.check(bam.card.init.cs.allPlusDateRE) # checks dfs and indicates if any changes should be made
plot.gam(bam.card.init.cs.allPlusDateRE) # plots effects - which are key for interpretation - and other diagnostics
summary(bam.card.init.cs.allPlusDateRE)

compareML(bam.card.init.cs.OnlyAge, bam.card.init.cs.allPlusDateRE)
compareML(bam.card.init.cs.all.7, bam.card.init.cs.allPlusDateRE)


